@@ -22,6 +22,10 @@ class BrokerConfiguration(Configuration):
     def exchange_store_path(self):
         return os.path.join(self.data_path, "exchange.database")
 
+    @property
+    def record_directory(self):
+        return os.path.join(self.data_path, "exchanges")
+
     def make_parser(self):
         """Parser factory for broker-specific options.
 
@@ -39,6 +43,7 @@ class BrokerConfiguration(Configuration):
               - C{https_proxy}
               - C{cloud}
               - C{otp}
+              - C{record}
         """
         parser = super(BrokerConfiguration, self).make_parser()
 
@@ -76,6 +81,8 @@ class BrokerConfiguration(Configuration):
         parser.add_option("--tags",
                           help="Comma separated list of tag names to be sent "
                                "to the server.")
+        parser.add_option("--record", action="store_true",
+                          help="Record data sent to the server on filesystem ")
         return parser
 
     @property
