@@ -9,6 +9,7 @@ from landscape.lib.log import log_failure
 from landscape.lib.fetch import fetch, FetchError
 from landscape.lib.tag import is_valid_tag_list
 from landscape.lib.network import get_fqdn
+from landscape.lib.vm_info import get_vm_info
 
 
 EC2_HOST = "169.254.169.254"
@@ -249,7 +250,8 @@ class RegistrationHandler(object):
                                "hostname": get_fqdn(),
                                "account_name": None,
                                "registration_password": None,
-                               "tags": tags}
+                               "tags": tags,
+                               "vm-info": get_vm_info()}
                     message.update(self._ec2_data)
                     self._exchange.send(message)
                 elif id.account_name:
@@ -263,7 +265,8 @@ class RegistrationHandler(object):
                                "account_name": id.account_name,
                                "registration_password": \
                                    id.registration_password,
-                               "tags": tags}
+                               "tags": tags,
+                               "vm-info": get_vm_info()}
                     message.update(self._ec2_data)
                     self._exchange.send(message)
                 else:
@@ -279,7 +282,8 @@ class RegistrationHandler(object):
                            "account_name": id.account_name,
                            "registration_password": id.registration_password,
                            "hostname": get_fqdn(),
-                           "tags": tags}
+                           "tags": tags,
+                           "vm-info": get_vm_info()}
                 self._exchange.send(message)
             else:
                 self._reactor.fire("registration-failed")
