@@ -5,10 +5,9 @@ import sys
 import os
 
 from twisted.internet.defer import Deferred, succeed
-from twisted.internet.utils import getProcessOutputAndValue
 
 from landscape.lib.sequenceranges import sequence_to_ranges
-from landscape.lib.twisted_util import gather_results
+from landscape.lib.twisted_util import gather_results, spawn_process
 from landscape.lib.fetch import fetch_async
 from landscape.lib.fs import touch_file
 
@@ -182,9 +181,8 @@ class PackageReporter(PackageTaskHandler):
         if self._config.force_smart_update or self._apt_sources_have_changed():
             args = ()
         else:
-            args = ("--after", "%d" % self.smart_update_interval)
-        result = getProcessOutputAndValue(self.smart_update_filename,
-                                          args=args)
+            args = ("--after", str(self.smart_update_interval))
+        result = spawn_process(self.smart_update_filename, args=args)
 
         def callback((out, err, code)):
             # smart-update --after N will exit with error code 1 when it
@@ -201,11 +199,24 @@ class PackageReporter(PackageTaskHandler):
             logging.debug("'%s' exited with status %d (out='%s', err='%s'" % (
                 self.smart_update_filename, code, out, err))
             touch_file(self._config.smart_update_stamp_filename)
-            return (out, err, code)
+            deferred = self._broker.call_if_accepted(
+                "package-reporter-result", self.send_result, code, err)
+            deferred.addCallback(lambda ignore: (out, err, code))
+            return deferred
 
         result.addCallback(callback)
         return result
 
+    def send_result(self, code, err):
+        """
+        Report the package reporter result to the server in a message.
+        """
+        message = {
+            "type": "package-reporter-result",
+            "code": code,
+            "err": err}
+        return self._broker.send_message(message, True)
+
     def handle_task(self, task):
         message = task.data
         if message["type"] == "package-ids":
