@@ -8,7 +8,6 @@ from twisted.application.app import startApplication
 from landscape.log import rotate_logs
 from landscape.reactor import TwistedReactor
 from landscape.deployment import get_versioned_persist, init_logging
-from landscape.lib import bpickle_dbus
 
 
 class LandscapeService(Service, object):
@@ -29,7 +28,12 @@ class LandscapeService(Service, object):
 
     def __init__(self, config):
         self.config = config
-        bpickle_dbus.install()
+        try:
+            from landscape.lib import bpickle_dbus
+        except ImportError:
+            pass
+        else:
+            bpickle_dbus.install()
         self.reactor = self.reactor_factory()
         if self.persist_filename:
             self.persist = get_versioned_persist(self)
