@@ -776,16 +776,16 @@ bus = session
                                   "-a", "account", "-t", "rex",
                                   "--script-users", "root, nobody"])
         setup(config)
-        contents = open(filename, "r").read().strip() + "\n"
-        self.assertEqual(contents, """\
-[client]
-url = https://localhost:8080/message-system
-bus = session
-computer_title = rex
-include_manager_plugins = ScriptExecution
-script_users = root, nobody
-account_name = account
-""")
+        parser = ConfigParser()
+        parser.read(filename)
+        self.assertEqual(
+            {"url": "https://localhost:8080/message-system",
+             "bus": "session",
+             "computer_title": "rex",
+             "include_manager_plugins": "ScriptExecution",
+             "script_users": "root, nobody",
+             "account_name": "account"},
+            dict(parser.items("client")))
 
     def test_silent_script_users_with_all_user(self):
         """
@@ -823,16 +823,17 @@ random_key = random_value
                                   "-a", "account", "-t", "rex",
                                   "--ping-url", "http://localhost/ping"])
         setup(config)
-        self.assertEqual(self.get_content(config), """\
-[client]
-log_level = debug
-registration_password = shared-secret
-computer_title = rex
-url = https://landscape.canonical.com/message-system
-ping_url = http://localhost/ping
-random_key = random_value
-account_name = account
-""")
+        parser = ConfigParser()
+        parser.read(filename)
+        self.assertEqual(
+            {"log_level": "debug",
+             "registration_password": "shared-secret",
+             "url": "https://landscape.canonical.com/message-system",
+             "ping_url": "http://localhost/ping",
+             "random_key": "random_value",
+             "computer_title": "rex",
+             "account_name": "account"},
+            dict(parser.items("client")))
 
     def test_setup_with_proxies_from_environment(self):
         os.environ["http_proxy"] = "http://environ"
@@ -875,15 +876,16 @@ registration_password = shared-secret
         config = self.get_config(["--config", filename, "--silent",
                                   "-a", "account", "-t", "rex"])
         setup(config)
-        self.assertEqual(self.get_content(config), """\
-[client]
-registration_password = shared-secret
-computer_title = rex
-http_proxy = http://environ
-https_proxy = https://environ
-url = https://landscape.canonical.com/message-system
-account_name = account
-""")
+        parser = ConfigParser()
+        parser.read(filename)
+        self.assertEqual(
+            {"registration_password": "shared-secret",
+             "url": "https://landscape.canonical.com/message-system",
+             "http_proxy": "http://environ",
+             "https_proxy": "https://environ",
+             "computer_title": "rex",
+             "account_name": "account"},
+            dict(parser.items("client")))
 
     def test_setup_prefers_proxies_from_config_over_environment(self):
         os.environ["http_proxy"] = "http://environ"
@@ -1087,7 +1089,7 @@ account_name = account
         main(["--disable", "-c", self.make_working_config()])
 
     def test_non_root(self):
-        self.mocker.reset() # Forget the thing done in setUp
+        self.mocker.reset()  # Forget the thing done in setUp
         self.mocker.replace("os.getuid")()
         self.mocker.result(1000)
         self.mocker.replay()
@@ -1097,7 +1099,7 @@ account_name = account
 
     def test_main_with_help_and_non_root(self):
         """It's possible to call 'landscape-config --help' as normal user."""
-        self.mocker.reset() # Forget the thing done in setUp
+        self.mocker.reset()  # Forget the thing done in setUp
         output = StringIO()
         self.mocker.replace("sys.stdout").write(ANY)
         self.mocker.call(output.write)
@@ -1107,7 +1109,7 @@ account_name = account
 
     def test_main_with_help_and_non_root_short(self):
         """It's possible to call 'landscape-config -h' as normal user."""
-        self.mocker.reset() # Forget the thing done in setUp
+        self.mocker.reset()  # Forget the thing done in setUp
         output = StringIO()
         self.mocker.replace("sys.stdout").write(ANY)
         self.mocker.call(output.write)
@@ -1143,12 +1145,12 @@ account_name = account
         options.read(config_filename)
 
         self.assertEqual(dict(options.items("client")),
-                          {"computer_title": "New Title",
-                           "account_name": "New Name",
-                           "registration_password": "New Password",
-                           "http_proxy": "http://new.proxy",
-                           "https_proxy": "https://new.proxy",
-                           "url": "http://new.url"})
+                         {"computer_title": "New Title",
+                          "account_name": "New Name",
+                          "registration_password": "New Password",
+                          "http_proxy": "http://new.proxy",
+                          "https_proxy": "https://new.proxy",
+                          "url": "http://new.url"})
 
     def test_import_from_empty_file(self):
         self.mocker.replay()
@@ -1299,7 +1301,7 @@ account_name = account
         self.assertEqual(dict(options.items("client")),
                          {"computer_title": "Old Title",
                           "account_name": "Old Name",
-                          "registration_password": "", # <==
+                          "registration_password": "",  # <==
                           "url": "http://old.url"})
 
     def test_import_from_url(self):
@@ -1463,7 +1465,7 @@ account_name = account
         config.data_path = data_path
         setup(config)
 
-        self.assertEquals("Hi there!", open(key_filename, "r").read())
+        self.assertEqual("Hi there!", open(key_filename, "r").read())
 
         options = ConfigParser()
         options.read(config_filename)
@@ -1490,7 +1492,7 @@ account_name = account
         options = ConfigParser()
         options.read(config_filename)
         self.assertEqual(options.get("client", "ssl_public_key"),
-                        "/some/filename")
+                         "/some/filename")
 
     # We test them individually since they must work individually.
     def test_import_from_url_honors_http_proxy(self):
@@ -1524,9 +1526,9 @@ account_name = account
                              "http://proxy",
                              "--import", "https://config.url"])
         except ImportOptionError:
-            pass # The returned content is empty.  We don't really
-                 # care for this test.  Mocker will ensure the tests
-                 # we care about are done.
+            pass  # The returned content is empty.  We don't really
+                  # care for this test.  Mocker will ensure the tests
+                  # we care about are done.
 
 
 class RegisterFunctionTest(LandscapeTest):
@@ -1670,7 +1672,6 @@ class RegisterFunctionTest(LandscapeTest):
                         "contact the server periodically.",
                         error=True)
 
-
         reactor_mock.stop()
 
         # Nothing else is printed!
@@ -1714,7 +1715,6 @@ class RegisterFunctionTest(LandscapeTest):
         # After a nice dance the configuration is reloaded.
         config_mock.reload()
 
-
         registration_mock.register()
         self.mocker.passthrough()
 
